# FastText Language Identification

[fasttext-language-identification](https://huggingface.co/facebook/fasttext-language-identification) is the companion language detector for the [NLLB](https://github.com/facebookresearch/fairseq/blob/nllb/README.md#lid-model) model


## Configuration

in `mycroft.conf` 

```javascript
  "language": {
    "detection_module": "ovos-lang-detector-fasttext-plugin"
  },
```
